summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorJon Marius Venstad <jvenstad@yahoo-inc.com>2018-10-16 11:58:03 +0200
committerJon Marius Venstad <jvenstad@yahoo-inc.com>2018-10-16 11:58:03 +0200
commit5170fe860be4c9e57d16305f16ac2089e9daa401 (patch)
tree4e11bffa3873525e1c9177edfddea2af019fe7a0
parent0e86f143e7b023803a97fd6b319b42c1bbcea579 (diff)
Content cluster, instead of storage cluster
-rw-r--r--controller-api/src/main/java/com/yahoo/vespa/hosted/controller/api/integration/configserver/ConfigServer.java2
-rw-r--r--controller-server/src/main/java/com/yahoo/vespa/hosted/controller/deployment/InternalStepRunner.java4
-rw-r--r--controller-server/src/test/java/com/yahoo/vespa/hosted/controller/integration/ConfigServerMock.java2
3 files changed, 4 insertions, 4 deletions
diff --git a/controller-api/src/main/java/com/yahoo/vespa/hosted/controller/api/integration/configserver/ConfigServer.java b/controller-api/src/main/java/com/yahoo/vespa/hosted/controller/api/integration/configserver/ConfigServer.java
index 4e71307dc65..4255c24c977 100644
--- a/controller-api/src/main/java/com/yahoo/vespa/hosted/controller/api/integration/configserver/ConfigServer.java
+++ b/controller-api/src/main/java/com/yahoo/vespa/hosted/controller/api/integration/configserver/ConfigServer.java
@@ -44,7 +44,7 @@ public interface ConfigServer {
Optional<Logs> getLogs(DeploymentId deployment, HashMap<String, String> queryParameters);
- List<String> getStorageClusters(DeploymentId deployment);
+ List<String> getContentClusters(DeploymentId deployment);
/**
* Set new status on en endpoint in one zone.
diff --git a/controller-server/src/test/java/com/yahoo/vespa/hosted/controller/integration/ConfigServerMock.java b/controller-server/src/test/java/com/yahoo/vespa/hosted/controller/integration/ConfigServerMock.java
index 45c4f2854d3..e29ffd824cd 100644
--- a/controller-server/src/test/java/com/yahoo/vespa/hosted/controller/integration/ConfigServerMock.java
+++ b/controller-server/src/test/java/com/yahoo/vespa/hosted/controller/integration/ConfigServerMock.java
@@ -303,7 +303,7 @@ public class ConfigServerMock extends AbstractComponent implements ConfigServer
}
@Override
- public List<String> getStorageClusters(DeploymentId deployment) {
+ public List<String> getContentClusters(DeploymentId deployment) {
return Collections.singletonList("music");
}
diff --git a/controller-server/src/main/java/com/yahoo/vespa/hosted/controller/deployment/InternalStepRunner.java b/controller-server/src/main/java/com/yahoo/vespa/hosted/controller/deployment/InternalStepRunner.java
index 0fde89849c7..1acf9bef363 100644
--- a/controller-server/src/main/java/com/yahoo/vespa/hosted/controller/deployment/InternalStepRunner.java
+++ b/controller-server/src/main/java/com/yahoo/vespa/hosted/controller/deployment/InternalStepRunner.java
@@ -468,11 +468,11 @@ public class InternalStepRunner implements StepRunner {
return deployments.build();
}
/** Returns all clusters in all current deployments of the given real application. */
private Map<ZoneId, List<String>> listClusters(ApplicationId id) {
ImmutableMap.Builder<ZoneId, List<String>> clusters = ImmutableMap.builder();
application(id).deployments().keySet()
- .forEach(zone -> clusters.put(zone, ImmutableList.copyOf(controller.configServer().getStorageClusters(new DeploymentId(id, zone)))));
+ .forEach(zone -> clusters.put(zone, ImmutableList.copyOf(controller.configServer().getContentClusters(new DeploymentId(id, zone)))));
return clusters.build();
}
@@ -468,11 +468,11 @@ public class InternalStepRunner implements StepRunner {
return deployments.build();
}
- /** Returns all clusters in all current deployments of the given real application. */
+ /** Returns all content clusters in all current deployments of the given real application. */
private Map<ZoneId, List<String>> listClusters(ApplicationId id) {
ImmutableMap.Builder<ZoneId, List<String>> clusters = ImmutableMap.builder();